Preston.dist(counts, start = 0.2, cex.octave = 1, cex.legend = 1, cex.pt = 1, ...)plot.[length(counts)/Est.no.of.spp]*100.nls, using a starting value, 0.2, recommended by Preston. The area under Preston curve provides an
extrapolated estimate of richness and thus an indication of the adequacy of a sampling effort. Preston called a
line placed at the 0th octave the veil line. He argued that species with abundances below the veil line have not
been detected due to inadequate sampling.dnorm, nlsdata(BCI.count)
BCI.ttl<-apply(BCI.count,2,sum)
Preston.dist(BCI.ttl)Run the code above in your browser using DataLab