mcmc.norm.hier(data, length = 1000, n.chains = 5)
mcmc.summary(M, burn.in = 0.5, cred = 0.95, conv.log = TRUE)mcmc.norm.hier.mcmc.norm.hier reurns a three dimensional (step x variable x chain) array. The function mcmc.summary returns a summary table containing credible intervals and the Gelman/Rubin convergence criterion, $\hat{R}$.mcmc.norm.hier provides posterior distributions of $\theta[j]$'s, $\mu, \sigma$ and $\tau$. The distributions are dervided from univariate conditional distributions dervided from the multivariate likelihood function. These conditional distributions provide a situation conducive to MCMC Gibbs sampling. Gelman et al. (2003) provide excellent summaries of these sorts of models.
The function mcmc.summary provides statsitical summaries for the output array from mcmc.norm.hier including credible intervals (empirically derived directly from chains) and the Gelman/Rubin convergence criterion, $\hat{R}$.R.hatlibrary(geoR)
data(cuckoo)
mcmc.norm.hier(cuckoo,10,2)Run the code above in your browser using DataLab