Learn R Programming

asbio (version 1.3-1)

portneuf: Portneuf River longitudinal N and P data.

Description

Portneuf River data from the Siphon Road site near Pocatello Idaho, downstream from an elemental P refinery.

Usage

data(portneuf)

Arguments

Format

A data frame with 176 observations on the following 3 variables.
date
Dates from 1998-01-15 to 2011-08-16
TKN
Total Kjeldahl nitrogen (measured as a percentage)
total.P
Total phosphorous (mg/L)

Idaho State Department of Environmental Quality