Learn R Programming

asbio (version 1.3-1)

power.z.test: Power analysis for a one sample z-test

Description

A power analysis for a one sample z-test. The function requires $\alpha$, $\sigma$, the effect size, the type of test (one tailed or two-tailed), and either power (1 - $\beta$) or n (sample size). If n is provided, then power is calculated. Conversely, if one provides power, but not n, then n is calculated.

Usage

power.z.test(sigma = 1, n = NULL, power = NULL, alpha = 0.05, effect = NULL, test = c("two.tail", "one.tail"), strict = FALSE)

Arguments

sigma
The population standard deviation.
n
The sample size. Not required if power is specified.
power
The desired power. Not required if n is specified.
alpha
Probability of type I error.
effect
Effect size.
test
One of two choices: "two.tail" or "one.tail".
strict
Causes the function to use a strict interpretation of power in a two-sided test. If strict = TRUE then power for a two sided test will include the probability of rejection in the opposite tail of the true effect. If strict = FALSE (the default) power will be half the value of $\alpha$ if the true effect size is zero.

Value

Returns a list
sigma
The prescribed population variance.
n
The sample size.
power
The power.
alpha
The type I error probability.
test
The type of test prescribed.
effect
The effect size.

References

Bain, L. J., and M. Engelhardt (1992) Introduction to Probability and Mathematical Statistics. Duxbury press. Belmont, CA, USA.

See Also

pnorm

Examples

Run this code
power.z.test(sigma=6,effect=5,power=.9,test="one.tail")

Run the code above in your browser using DataLab