Learn R Programming

asbio (version 0.4-11)

sedum.ts: CO2 exchange time series data

Description

Gurevitch et al. (1986) demonstrated time series analysis with data describing change in CO2 concentration of airstreams passing over a Sedum wrightii test plant.

Usage

data(sedum.ts)

Arguments

source

Gurevitch, J. and S. T. Chester, Jr. 1986. Analysis of repeated measures experiments. Ecology 67(1): 251-255.