Usage
ci.prat.ak(y1, n1, pi2 = NULL, method = "ac", conf = 0.95, bonf = FALSE,
bootCI.method = "perc", R = 1000, sigma.t = NULL, r = length(y1), gamma.hyper = 1,
beta.hyper = 1)
Arguments
y1
The ratio numerator number of successes. A scalar or vector.
n1
The ratio numerator number of trials. A scalar or vector of length(y1)
pi2
The denominator proportion. A scalar or vector of length(y1)
method
One of "ac", "wald", "noether-fixed", "boot", "fixed-log" or "bayes" for the Agresti-Coull-adjusted, adjusted Wald, noether-fixed, bootstrapping, fixed-log and Bayes-beta, methods, respectively. Partial distinct names can be use
conf
The level of confidence, i.e. 1 - P(type I error).
bonf
Logical, indicating whether or not Bonferroni corrections should be applied for simultaneous inference if y1, y2, n1 and n2 are vectors.
bootCI.method
If method = "boot" the type of bootstrap confidence interval to calculate. One of "norm", "basic", "perc", "BCa", or "student". See
ci R
If method = "boot" the number of bootstrap samples to take. See ci.boot for more information. sigma.t
If method = "boot" and bootCI.methd = "student" a vector of standard errors in association with studentized intervals. See ci.boot for more information. r
The number of ratios to which family-wise inferences are being made. Assumed to be length(y1).
gamma.hyper
If method = "bayes". A scalar or vector. Value(s) for the first hyperparameter for the beta prior distribution.
beta.hyper
If method = "bayes". A scalar or vector. Value(s) for the second hyperparameter for the beta prior distribution.