Learn R Programming

asbio (version 1.3-1)

sedum.ts: CO2 exchange time series data

Description

Gurevitch et al. (1986) demonstrated time series analysis with data describing change in CO$_2$ concentration of airstreams passing over a Sedum wrightii test plant.

Usage

data(sedum.ts)

Arguments

Format

A data frame with 24 observations on the following 3 variables.
exchange
CO$_2$ exchange, measured as: [change in CO$_2$ concentration (g/mg)]/ plant fresh mass (g). Thus units are 1/mg. Positive values indicate net CO$_2$ uptake while negative values indicate net CO2 output.
time
A numeric vector indicating two hour intervals
treatment
Dry = water withheld for several week, Wet = plant well watered.

Gurevitch, J. and S. T. Chester, Jr (1986) Analysis of repeated measures experiments. Ecology 67(1): 251-255.